@@ -12,3 +12,6 @@ class BaseItem(scrapy.Item):
 
     def to_json_str(self):
         return json.dumps(self.to_dict(), ensure_ascii=False)
+
+    def queue_names(self):
+        return []
