@@ -5,6 +5,7 @@ import pika
 import os
 import json
 
+
 class AMQPPipeline(object):
     def __init__(self,
                  mq_dev_user,
@@ -17,10 +18,8 @@ class AMQPPipeline(object):
                  mq_prod_host,
                  mq_prod_port,
                  mq_prod_vhost):
-        self.parameters_dev = pika.URLParameters(
-            f'amqp://{mq_dev_user}:{mq_dev_password}@{mq_dev_host}:{mq_dev_port}/{mq_dev_vhost}') if mq_dev_host else None
-        self.parameters_prod = pika.URLParameters(
-            f'amqp://{mq_prod_user}:{mq_prod_password}@{mq_prod_host}:{mq_prod_port}/{mq_prod_vhost}') if mq_prod_host else None
+        self.parameters_dev = pika.URLParameters(f'amqp://{mq_dev_user}:{mq_dev_password}@{mq_dev_host}:{mq_dev_port}/{mq_dev_vhost}') if mq_dev_host else None
+        self.parameters_prod = pika.URLParameters(f'amqp://{mq_prod_user}:{mq_prod_password}@{mq_prod_host}:{mq_prod_port}/{mq_prod_vhost}') if mq_prod_host else None
         self.queue_names_dev = []
         self.queue_names_prod = []
 
@@ -58,32 +57,41 @@ class AMQPPipeline(object):
             for task in tasks:
                 env = task['env']
                 queue_name = task['queue_name']
-                queue_data = json.dumps({
-                    "filename": item.get('oss_filename'),
-                    "channel": spider.name,
-                    "source_id": item.get('unique_id'),
-                }, ensure_ascii=False)
+
+                amqp_queue_use_item = spider.settings.get(
+                    'AMQP_QUEUE_USE_ITEM')
+                queue_data = {}
+                if amqp_queue_use_item == True:
+                    data = item
+                    queue_data = json.dumps(data.to_json_str(), ensure_ascii=False)
+                else:
+                    queue_data = json.dumps({
+                        "filename": item.get('oss_filename'),
+                        "channel": spider.name,
+                        "source_id": item.get('unique_id'),
+                    }, ensure_ascii=False)
+
                 if env == 'dev':
                     if not self.channel_dev:
                         continue
                     try:
                         if not queue_name in self.queue_names_dev:
                             self.channel_dev.queue_declare(queue_name,
-                                                        passive=False,
-                                                        durable=True,
-                                                        exclusive=False,
-                                                        auto_delete=False,
-                                                        arguments=None,
-                                                        )
+                                                           passive=False,
+                                                           durable=True,
+                                                           exclusive=False,
+                                                           auto_delete=False,
+                                                           arguments=None,
+                                                           )
                             self.queue_names_dev.append(queue_name)
                         spider.logger.info(f'declare queue {queue_name}')
                         self.channel_dev.basic_publish('',
-                                                    queue_name,
-                                                    queue_data,
-                                                    pika.BasicProperties(
-                                                        content_type='application/json',
-                                                        delivery_mode=2),
-                                                    )
+                                                       queue_name,
+                                                       queue_data,
+                                                       pika.BasicProperties(
+                                                           content_type='application/json',
+                                                           delivery_mode=2),
+                                                       )
                     except:
                         pass
                 else:
